==> geneRecommender_1.20.0.zip: geneRecommender/doc/geneRecommender.R <==
###################################################
### chunk number 1: 
###################################################
library(geneRecommender)
data(geneData)
my.query <- c("31613_at", "31712_at", "31497_at")
normalized.data <- gr.normalize(geneData)
gr.main(normalized.data, my.query, ngenes = 10)


###################################################
### chunk number 2: 
###################################################
gr.cv(normalized.data, my.query)


###################################################
### chunk number 3: 
###################################################
normal.normalized.data <- qnorm((normalized.data + 1)/2)
gr.main(normal.normalized.data, my.query, ngenes = 10)


###################################################
### chunk number 4: 
###################################################
my.fun.1 <- function(input.vector){
  sum(input.vector^(1/2), na.rm = T)
}
gr.main(normalized.data, my.query, ngenes = 10, fun = my.fun.1)


###################################################
### chunk number 5: 
###################################################
my.fun.2 <- function(input.vector){
  1
}
gr.main(normalized.data, my.query, ngenes = 10, fun = my.fun.2)


###################################################
### chunk number 6: 
###################################################
options(digits = 2)
gr.main(normalized.data, my.query, ngenes = 10, extra = T)


###################################################
### chunk number 7: 
###################################################
toLatex(sessionInfo())

==> geneRecommender_1.22.0.zip: geneRecommender/doc/geneRecommender.R <==
###################################################
### chunk number 1: 
###################################################
#line 54 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpalYRtc/R.INSTALL2603cd1/geneRecommender/inst/doc/geneRecommender.Rnw"
library(geneRecommender)
data(geneData)
my.query <- c("31613_at", "31712_at", "31497_at")
normalized.data <- gr.normalize(geneData)
gr.main(normalized.data, my.query, ngenes = 10)


###################################################
### chunk number 2: 
###################################################
#line 78 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpalYRtc/R.INSTALL2603cd1/geneRecommender/inst/doc/geneRecommender.Rnw"
gr.cv(normalized.data, my.query)


###################################################
### chunk number 3: 
###################################################
#line 109 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpalYRtc/R.INSTALL2603cd1/geneRecommender/inst/doc/geneRecommender.Rnw"
normal.normalized.data <- qnorm((normalized.data + 1)/2)
gr.main(normal.normalized.data, my.query, ngenes = 10)


###################################################
### chunk number 4: 
###################################################
#line 128 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpalYRtc/R.INSTALL2603cd1/geneRecommender/inst/doc/geneRecommender.Rnw"
my.fun.1 <- function(input.vector){
  sum(input.vector^(1/2), na.rm = T)
}
gr.main(normalized.data, my.query, ngenes = 10, fun = my.fun.1)


###################################################
### chunk number 5: 
###################################################
#line 145 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpalYRtc/R.INSTALL2603cd1/geneRecommender/inst/doc/geneRecommender.Rnw"
my.fun.2 <- function(input.vector){
  1
}
gr.main(normalized.data, my.query, ngenes = 10, fun = my.fun.2)


###################################################
### chunk number 6: 
###################################################
#line 159 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpalYRtc/R.INSTALL2603cd1/geneRecommender/inst/doc/geneRecommender.Rnw"
options(digits = 2)
gr.main(normalized.data, my.query, ngenes = 10, extra = T)


###################################################
### chunk number 7: 
###################################################
#line 201 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpalYRtc/R.INSTALL2603cd1/geneRecommender/inst/doc/geneRecommender.Rnw"
toLatex(sessionInfo())
